@@ -90,8 +90,11 @@ NetworkManagerApplet::NetworkManagerApplet(QObject * parent, const QVariantList
     connect(&m_overlayTimeline, SIGNAL(valueChanged(qreal)), this, SLOT(repaint()));
 
     m_svg = new Plasma::Svg(this);
-    m_svg->setImagePath("icons/network2");
+    m_svg->setImagePath("icons/network");
     m_svg->setContainsMultipleImages(true);
+    m_svgMobile = new Plasma::Svg(this);
+    m_svgMobile->setImagePath("icons/network2");
+    m_svgMobile->setContainsMultipleImages(true);
     m_meterBgSvg = new Plasma::FrameSvg(this);
     m_meterBgSvg->setImagePath("widgets/bar_meter_horizontal");
     m_meterBgSvg->setElementPrefix("bar-inactive");
@@ -102,8 +105,9 @@ NetworkManagerApplet::NetworkManagerApplet(QObject * parent, const QVariantList
     m_interfaces = Solid::Control::NetworkManagerNm09::networkInterfaces();
     if (!m_interfaces.isEmpty()) {
         qSort(m_interfaces.begin(), m_interfaces.end(), networkInterfaceLessThan);
-        m_activeInterface = m_interfaces.first();
-        m_activeSystrayInterface = m_activeInterface;
+        setActiveInterface(m_interfaces.first());
+        setActiveSystrayInterface(m_activeInterface);
+        m_activeSystrayInterfaceState = Solid::Control::NetworkInterfaceNm09::UnknownState;
     }
 
     // Just to make sure the kded module is loaded before initializing the activatables.
@@ -411,7 +415,11 @@ void NetworkManagerApplet::paintInterface(QPainter * p, const QStyleOptionGraphi
     if (el.isEmpty()) {
         painter.drawPixmap(QPoint(0,0), m_pixmap);
     } else {
-        m_svg->paint(&painter, rect, el);
+        if (el.startsWith("network-mobile")) {
+            m_svgMobile->paint(&painter, rect, el);
+        } else {
+            m_svg->paint(&painter, rect, el);
+        }
     }
 
     paintStatusOverlay(&painter, rect);
@@ -477,8 +485,8 @@ void NetworkManagerApplet::networkInterfaceAdded(const QString & uni)
     m_interfaces = Solid::Control::NetworkManagerNm09::networkInterfaces();
 
     if (!m_activeInterface) {
-        m_activeInterface = m_interfaces.first();
-        m_activeSystrayInterface = m_activeInterface;
+        setActiveInterface(m_interfaces.first());
+        setActiveSystrayInterface(m_activeInterface);
     }
 
     setupInterfaceSignals();
@@ -490,18 +498,18 @@ void NetworkManagerApplet::networkInterfaceRemoved(const QString & uni)
     // update the tray icon
     m_interfaces = Solid::Control::NetworkManagerNm09::networkInterfaces();
 
-    if (uni == m_activeInterface->uni()) {
+    if (uni == m_lastActiveInterfaceUni) {
         if (m_interfaces.isEmpty()) {
-            m_activeInterface = 0;
+            setActiveInterface(0);
         } else {
             qSort(m_interfaces.begin(), m_interfaces.end(), networkInterfaceLessThan);
-            m_activeInterface = m_interfaces.first();
+            setActiveInterface(m_interfaces.first());
             m_activeInterfaceState = Solid::Control::NetworkInterfaceNm09::UnknownState;
         }
     }
     setupInterfaceSignals();
-    if (uni == m_activeSystrayInterface->uni()) {
-        m_activeSystrayInterface = 0;
+    if (uni == m_lastActiveSystrayInterfaceUni) {
+        setActiveSystrayInterface(0);
         resetActiveSystrayInterface();
     } else {
         interfaceConnectionStateChanged();
@@ -521,7 +529,7 @@ void NetworkManagerApplet::interfaceConnectionStateChanged()
             case Solid::Control::NetworkInterfaceNm09::IPConfig:
             case Solid::Control::NetworkInterfaceNm09::IPCheck:
             case Solid::Control::NetworkInterfaceNm09::Secondaries:
-                m_activeSystrayInterface = interface;
+                setActiveSystrayInterface(interface);
                 m_activeSystrayInterfaceState = Solid::Control::NetworkInterfaceNm09::UnknownState;
                 break;
             default:
@@ -529,7 +537,7 @@ void NetworkManagerApplet::interfaceConnectionStateChanged()
             }
         }
     } else if (!m_activeSystrayInterface) {
-        m_activeSystrayInterface = m_activeInterface;
+        setActiveSystrayInterface(m_activeInterface);
         m_activeSystrayInterfaceState = m_activeInterfaceState;
     }
     if (m_activeSystrayInterface) {
@@ -851,10 +859,16 @@ void NetworkManagerApplet::userWirelessEnabledChanged(bool enabled)
 void NetworkManagerApplet::managerStatusChanged(Solid::Networking::Status status)
 {
     //kDebug() << "managerstatuschanged";
-    if (Solid::Networking::Unknown == status ) {
-        // FIXME: Do something smart
+    m_interfaces = Solid::Control::NetworkManagerNm09::networkInterfaces();
+    if (status == Solid::Networking::Unknown) {
+        setActiveInterface(0);
+        setActiveSystrayInterface(0);
     } else {
-        // ...
+        if (!m_interfaces.isEmpty()) {
+            qSort(m_interfaces.begin(), m_interfaces.end(), networkInterfaceLessThan);
+            setActiveInterface(m_interfaces.first());
+            setActiveSystrayInterface(m_activeInterface);
+        }
     }
     setupInterfaceSignals();
     updatePixmap();
@@ -960,7 +974,7 @@ void NetworkManagerApplet::updateActiveInterface(bool hasDefaultRoute)
     RemoteInterfaceConnection *ic = qobject_cast<RemoteInterfaceConnection*>(sender());
     if (hasDefaultRoute) {
         // TODO: add support for VpnRemoteInterfaceConnection's, which have "any" as ic->deviceUni().
-        m_activeInterface = Solid::Control::NetworkManagerNm09::findNetworkInterface(ic->deviceUni());
+        setActiveInterface(Solid::Control::NetworkManagerNm09::findNetworkInterface(ic->deviceUni()));
         connect(m_activeInterface, SIGNAL(destroyed(QObject *)), SLOT(_k_destroyed(QObject *)));
         resetActiveSystrayInterface();
     }
@@ -970,19 +984,19 @@ void NetworkManagerApplet::_k_destroyed(QObject *object)
 {
     Q_UNUSED(object);
     if (object == m_activeInterface) {
-        m_activeInterface = 0;
+        setActiveInterface(0);
     }
     if (object == m_activeSystrayInterface) {
-        m_activeSystrayInterface = 0;
+        setActiveSystrayInterface(0);
     }
 }
 
 void NetworkManagerApplet::resetActiveSystrayInterface()
 {
-    if (m_activeSystrayInterface && m_activeSystrayInterface->uni() == m_activeInterface->uni()) {
+    if (m_activeInterface && m_activeSystrayInterface && m_activeSystrayInterface->uni() == m_activeInterface->uni()) {
         return;
     }
-    m_activeSystrayInterface = m_activeInterface;
+    setActiveSystrayInterface(m_activeInterface);
     m_activeSystrayInterfaceState = m_activeInterfaceState;
     if (m_activeSystrayInterfaceState == Solid::Control::NetworkInterfaceNm09::Activated) {
         setStatusOverlay(QPixmap());
@@ -1005,4 +1019,22 @@ void NetworkManagerApplet::activatablesDisappeared()
     update();
 }
 
+void NetworkManagerApplet::setActiveInterface(Solid::Control::NetworkInterfaceNm09 * iface)
+{
+    m_activeInterface = iface;
+
+    if (m_activeInterface) {
+        m_lastActiveInterfaceUni = m_activeInterface->uni();
+    }
+}
+
+void NetworkManagerApplet::setActiveSystrayInterface(Solid::Control::NetworkInterfaceNm09 * iface)
+{
+    m_activeSystrayInterface = iface;
+
+    if (m_activeSystrayInterface) {
+        m_lastActiveSystrayInterfaceUni = m_activeSystrayInterface->uni();
+    }
+}
+
 #include "networkmanager.moc"
