@@ -339,9 +339,12 @@ void ManageConnectionWidget::updateTabStates()
                             break;
                         case Solid::Control::ModemNetworkInterfaceNm09::GsmUmts:
                         case Solid::Control::ModemNetworkInterfaceNm09::CdmaEvdo:
-                        /* TODO: case Solid::Control::ModemNetworkInterfaceNm09::Lte: */
+                        case Solid::Control::ModemNetworkInterfaceNm09::Lte:
                             hasCellular = true;
                             break;
+                        case Solid::Control::ModemNetworkInterfaceNm09::None:
+                            kWarning() << "Unhandled modem sub type: Solid::Control::ModemNetworkInterfaceNm09::None";
+                            break;
                     }
                 }
             }
@@ -453,7 +456,6 @@ void ManageConnectionWidget::exportClicked()
     QTreeWidgetItem * item = selectedItem();
     Knm::Connection * con = 0;
     QString connectionId = item->data(0, ConnectionIdRole).toString();
-    Knm::Connection::Type type = (Knm::Connection::Type)item->data(0, ConnectionTypeRole).toUInt();
     if (connectionId.isEmpty()) {
         kDebug() << "selected item had no connectionId!";
         return;
